==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/fy.py <==
info = {
    "name": "fy",
    "date_order": "DMY",
    "january": [
        "jannewaris",
        "jan"
    ],
    "february": [
        "febrewaris",
        "feb"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maaie",
        "mai"
    ],
    "june": [
        "juny",
        "jun"
    ],
    "july": [
        "july",
        "jul"
    ],
    "august": [
        "augustus",
        "aug"
    ],
    "september": [
        "septimber",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "novimber",
        "nov"
    ],
    "december": [
        "desimber",
        "des"
    ],
    "monday": [
        "moandei",
        "mo"
    ],
    "tuesday": [
        "tiisdei",
        "ti"
    ],
    "wednesday": [
        "woansdei",
        "wo"
    ],
    "thursday": [
        "tongersdei",
        "to"
    ],
    "friday": [
        "freed",
        "fr"
    ],
    "saturday": [
        "sneon",
        "so"
    ],
    "sunday": [
        "snein",
        "si"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jier"
    ],
    "month": [
        "moanne"
    ],
    "week": [
        "wike"
    ],
    "day": [
        "dei"
    ],
    "hour": [
        "oere"
    ],
    "minute": [
        "minút"
    ],
    "second": [
        "sekonde"
    ],
    "relative-type": {
        "1 year ago": [
            "foarich jier"
        ],
        "0 year ago": [
            "dit jier"
        ],
        "in 1 year": [
            "folgjend jier"
        ],
        "1 month ago": [
            "foarige moanne"
        ],
        "0 month ago": [
            "dizze moanne"
        ],
        "in 1 month": [
            "folgjende moanne"
        ],
        "1 week ago": [
            "foarige wike"
        ],
        "0 week ago": [
            "dizze wike"
        ],
        "in 1 week": [
            "folgjende wike"
        ],
        "1 day ago": [
            "gisteren"
        ],
        "0 day ago": [
            "vandaag"
        ],
        "in 1 day": [
            "morgen"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "nu"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "oer (\\d+) jier"
        ],
        "\\1 year ago": [
            "(\\d+) jier lyn"
        ],
        "in \\1 month": [
            "oer (\\d+) moanne",
            "oer (\\d+) moannen"
        ],
        "\\1 month ago": [
            "(\\d+) moanne lyn",
            "(\\d+) moannen lyn"
        ],
        "in \\1 week": [
            "oer (\\d+) wike",
            "oer (\\d+) wiken"
        ],
        "\\1 week ago": [
            "(\\d+) wike lyn",
            "(\\d+) wiken lyn"
        ],
        "in \\1 day": [
            "oer (\\d+) dei",
            "oer (\\d+) deien"
        ],
        "\\1 day ago": [
            "(\\d+) dei lyn",
            "(\\d+) deien lyn"
        ],
        "in \\1 hour": [
            "oer (\\d+) oere"
        ],
        "\\1 hour ago": [
            "(\\d+) oere lyn"
        ],
        "in \\1 minute": [
            "oer (\\d+) minút",
            "oer (\\d+) minuten"
        ],
        "\\1 minute ago": [
            "(\\d+) minút lyn",
            "(\\d+) minuten lyn"
        ],
        "in \\1 second": [
            "oer (\\d+) sekonde",
            "oer (\\d+) sekonden"
        ],
        "\\1 second ago": [
            "(\\d+) sekonde lyn",
            "(\\d+) sekonden lyn"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/fy.py <==
info = {
    "name": "fy",
    "date_order": "DMY",
    "january": [
        "jan",
        "jannewaris"
    ],
    "february": [
        "feb",
        "febrewaris"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "maaie",
        "mai"
    ],
    "june": [
        "jun",
        "juny"
    ],
    "july": [
        "jul",
        "july"
    ],
    "august": [
        "aug",
        "augustus"
    ],
    "september": [
        "sep",
        "septimber"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "novimber"
    ],
    "december": [
        "des",
        "desimber"
    ],
    "monday": [
        "mo",
        "moandei"
    ],
    "tuesday": [
        "ti",
        "tiisdei"
    ],
    "wednesday": [
        "wo",
        "woansdei"
    ],
    "thursday": [
        "to",
        "tongersdei"
    ],
    "friday": [
        "fr",
        "freed"
    ],
    "saturday": [
        "sneon",
        "so"
    ],
    "sunday": [
        "si",
        "snein"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jier"
    ],
    "month": [
        "moanne"
    ],
    "week": [
        "wike"
    ],
    "day": [
        "dei"
    ],
    "hour": [
        "oere"
    ],
    "minute": [
        "minút"
    ],
    "second": [
        "sekonde"
    ],
    "relative-type": {
        "0 day ago": [
            "vandaag"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "dizze moanne"
        ],
        "0 second ago": [
            "nu"
        ],
        "0 week ago": [
            "dizze wike"
        ],
        "0 year ago": [
            "dit jier"
        ],
        "1 day ago": [
            "gisteren"
        ],
        "1 month ago": [
            "foarige moanne"
        ],
        "1 week ago": [
            "foarige wike"
        ],
        "1 year ago": [
            "foarich jier"
        ],
        "in 1 day": [
            "morgen"
        ],
        "in 1 month": [
            "folgjende moanne"
        ],
        "in 1 week": [
            "folgjende wike"
        ],
        "in 1 year": [
            "folgjend jier"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) dei lyn",
            "(\\d+) deien lyn"
        ],
        "\\1 hour ago": [
            "(\\d+) oere lyn"
        ],
        "\\1 minute ago": [
            "(\\d+) minuten lyn",
            "(\\d+) minút lyn"
        ],
        "\\1 month ago": [
            "(\\d+) moanne lyn",
            "(\\d+) moannen lyn"
        ],
        "\\1 second ago": [
            "(\\d+) sekonde lyn",
            "(\\d+) sekonden lyn"
        ],
        "\\1 week ago": [
            "(\\d+) wike lyn",
            "(\\d+) wiken lyn"
        ],
        "\\1 year ago": [
            "(\\d+) jier lyn"
        ],
        "in \\1 day": [
            "oer (\\d+) dei",
            "oer (\\d+) deien"
        ],
        "in \\1 hour": [
            "oer (\\d+) oere"
        ],
        "in \\1 minute": [
            "oer (\\d+) minuten",
            "oer (\\d+) minút"
        ],
        "in \\1 month": [
            "oer (\\d+) moanne",
            "oer (\\d+) moannen"
        ],
        "in \\1 second": [
            "oer (\\d+) sekonde",
            "oer (\\d+) sekonden"
        ],
        "in \\1 week": [
            "oer (\\d+) wike",
            "oer (\\d+) wiken"
        ],
        "in \\1 year": [
            "oer (\\d+) jier"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
